==> grimoirejs-cauldron-2.999.1000.tgz: package/lib/buildUtil/generate-exposure.js <==
"use strict";

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _getIterator2 = require("babel-runtime/core-js/get-iterator");

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var generateIndex = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    var cwd, pkgJson, projectSuffix, destFileLocation, mainFileLocation, basePath, detectedFiles, pathMap, interfaces, i, relative, absolute, content, key, separated, keyPath, structureObject, _keyPath, jsonCode, objectCode, imports, _keyPath2, index, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, pathes, templateArgs;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            cwd = process.cwd();
            _context.t0 = JSON;
            _context.next = 5;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 5:
            _context.t1 = _context.sent;
            pkgJson = _context.t0.parse.call(_context.t0, _context.t1);
            projectSuffix = (0, _common.getSuffix)(pkgJson.name);
            destFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.dest));
            mainFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.main));
            basePath = _path2.default.join(cwd, _yargs.argv.src); // absolute path of source directory

            _context.next = 13;
            return (0, _asyncHelper.globAsync)(_path2.default.join(cwd, _yargs.argv.src, _yargs.argv.ts ? "**/*.ts" : "**/*.js"));

          case 13:
            detectedFiles = _context.sent;
            // glob all javascript files
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("CWD:" + cwd + " Project Suffix:" + projectSuffix + "\n destination:" + destFileLocation + "\n mainFile:" + mainFileLocation + "\n basePath:" + basePath + "\n\n DetectedFiles:\n" + detectedFiles));
            }
            pathMap = {};
            interfaces = [];
            // listup files containing `export default`

            i = 0;

          case 18:
            if (!(i < detectedFiles.length)) {
              _context.next = 35;
              break;
            }

            relative = _path2.default.relative(basePath, detectedFiles[i]);
            absolute = _path2.default.resolve(detectedFiles[i]);

            if (!(destFileLocation === absolute || mainFileLocation === absolute || /\.d\.ts$/.test(absolute))) {
              _context.next = 23;
              break;
            }

            return _context.abrupt("continue", 32);

          case 23:
            _context.next = 25;
            return (0, _asyncHelper.readFileAsync)(detectedFiles[i]);

          case 25:
            content = _context.sent;

            if (!(content.indexOf("interface ") >= 0 && content.indexOf("class ") < 0)) {
              _context.next = 31;
              break;
            }

            // to ignore interfaces
            interfaces.push(relative);
            return _context.abrupt("continue", 32);

          case 31:
            pathMap[relative] = _path2.default.parse(relative);

          case 32:
            i++;
            _context.next = 18;
            break;

          case 35:
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("Target files:\n"));
              for (key in pathMap) {
                console.log(_chalk2.default.cyan(key + " : \"" + pathMap[key] + "\""));
              }
            }
            // separate relative path by '/' or '\'
            separated = {};

            for (keyPath in pathMap) {
              separated[keyPath] = pathMap[keyPath].dir.split(_path2.default.sep);
              separated[keyPath].push(pathMap[keyPath].name); // last element of separated[path] is file name without extension
            }
            // make structure of index
            structureObject = {};

            for (_keyPath in separated) {
              generateStructureRecursively(structureObject, separated[_keyPath], "");
            }
            jsonCode = (0, _stringify2.default)(structureObject, null, "  ");
            objectCode = asJSIndex(jsonCode, separated);
            imports = [];

            for (_keyPath2 in separated) {
              imports.push({
                path: "./" + _keyPath2.replace(/\.js|\.ts/g, ""),
                key: (0, _common.jsSafeString)(separated[_keyPath2].reduce(function (p, c) {
                  return p + c;
                }))
              });
            }
            index = 0;
            _iteratorNormalCompletion = true;
            _didIteratorError = false;
            _iteratorError = undefined;
            _context.prev = 48;

            for (_iterator = (0, _getIterator3.default)(interfaces); !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              pathes = _step.value;

              index++;
              imports.push({
                path: "./" + pathes.replace(/\.ts/g, ""),
                key: "__INTERFACE__" + index
              });
            }
            _context.next = 56;
            break;

          case 52:
            _context.prev = 52;
            _context.t2 = _context["catch"](48);
            _didIteratorError = true;
            _iteratorError = _context.t2;

          case 56:
            _context.prev = 56;
            _context.prev = 57;

            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }

          case 59:
            _context.prev = 59;

            if (!_didIteratorError) {
              _context.next = 62;
              break;
            }

            throw _iteratorError;

          case 62:
            return _context.finish(59);

          case 63:
            return _context.finish(56);

          case 64:
            templateArgs = {
              exportObject: objectCode,
              imports: imports,
              mainPath: "./" + _path2.default.relative(basePath, mainFileLocation).replace(/\.ts|\.js/g, ""),
              registerCode: projectSuffix ? "window[\"GrimoireJS\"].lib." + projectSuffix + " = __EXPOSE__;" : "window[\"GrimoireJS\"][\"__VERSION__\"]=__VERSION__;\n",
              version: pkgJson.version,
              name: pkgJson.name
            };
            _context.t3 = _asyncHelper.writeFileAsync;
            _context.t4 = _path2.default.join(cwd, _yargs.argv.dest);
            _context.next = 69;
            return (0, _asyncHelper.templateAsync)(_path2.default.normalize(__dirname + "/../../src/buildUtil/index-template.template"), templateArgs);

          case 69:
            _context.t5 = _context.sent;
            _context.next = 72;
            return (0, _context.t3)(_context.t4, _context.t5);

          case 72:
            _context.next = 77;
            break;

          case 74:
            _context.prev = 74;
            _context.t6 = _context["catch"](0);

            console.log(_context.t6);

          case 77:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 74], [48, 52, 56, 64], [57,, 59, 63]]);
  }));

  return function generateIndex() {
    return _ref.apply(this, arguments);
  };
}();

var _asyncHelper = require("../async-helper");

var _yargs = require("yargs");

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

var _common = require("./common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function generateStructureRecursively(obj, sepDirs, basePath) {
  if (sepDirs.length < 2) {
    return;
  }
  if (sepDirs[0] === '') {
    obj[sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
    return;
  }
  basePath = basePath + sepDirs[0];
  if (sepDirs[0] !== '' && obj[sepDirs[0]] === void 0) {
    obj[sepDirs[0]] = {};
  }
  if (sepDirs.length > 2) {
    generateStructureRecursively(obj[sepDirs[0]], sepDirs.slice(1), basePath);
  } else if (sepDirs.length === 2) {
    obj[sepDirs[0]][sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
  }
}

function asJSIndex(jsonStr, sepDirs) {
  for (var pathKey in sepDirs) {
    var keyName = (0, _common.jsSafeString)(sepDirs[pathKey].reduce(function (p, c) {
      return p + c;
    }));
    var regex = new RegExp("(: *)\"" + keyName + "\"");
    jsonStr = jsonStr.replace(regex, "$1" + keyName);
  }
  return jsonStr;
}

generateIndex();

==> grimoirejs-cauldron-3.1.0.tgz: package/lib/buildUtil/generate-exposure.js <==
"use strict";

var _regenerator = require("babel-runtime/regenerator");

var _regenerator2 = _interopRequireDefault(_regenerator);

var _getIterator2 = require("babel-runtime/core-js/get-iterator");

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _stringify = require("babel-runtime/core-js/json/stringify");

var _stringify2 = _interopRequireDefault(_stringify);

var _asyncToGenerator2 = require("babel-runtime/helpers/asyncToGenerator");

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var generateIndex = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee() {
    var cwd, pkgJson, projectSuffix, destFileLocation, mainFileLocation, basePath, detectedFiles, pathMap, interfaces, i, relative, absolute, content, key, separated, keyPath, structureObject, _keyPath, jsonCode, objectCode, imports, _keyPath2, index, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, pathes, templateArgs, index_ts_content, dest_path;

    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            _context.prev = 0;
            cwd = process.cwd();
            _context.t0 = JSON;
            _context.next = 5;
            return (0, _asyncHelper.readFileAsync)(_path2.default.join(cwd, "package.json"));

          case 5:
            _context.t1 = _context.sent;
            pkgJson = _context.t0.parse.call(_context.t0, _context.t1);
            projectSuffix = (0, _common.getSuffix)(pkgJson.name);
            destFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.dest));
            mainFileLocation = _path2.default.resolve(_path2.default.join(cwd, _yargs.argv.main));
            basePath = _path2.default.join(cwd, _yargs.argv.src); // absolute path of source directory

            _context.next = 13;
            return (0, _asyncHelper.globAsync)(_path2.default.join(cwd, _yargs.argv.src, _yargs.argv.ts ? "**/*.ts" : "**/*.js"));

          case 13:
            detectedFiles = _context.sent;
            // glob all javascript files
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("CWD:" + cwd + " Project Suffix:" + projectSuffix + "\n destination:" + destFileLocation + "\n mainFile:" + mainFileLocation + "\n basePath:" + basePath + "\n\n DetectedFiles:\n" + detectedFiles));
            }
            pathMap = {};
            interfaces = [];
            // listup files containing `export default`

            i = 0;

          case 18:
            if (!(i < detectedFiles.length)) {
              _context.next = 35;
              break;
            }

            relative = _path2.default.relative(basePath, detectedFiles[i]);
            absolute = _path2.default.resolve(detectedFiles[i]);

            if (!(destFileLocation === absolute || mainFileLocation === absolute || /\.d\.ts$/.test(absolute))) {
              _context.next = 23;
              break;
            }

            return _context.abrupt("continue", 32);

          case 23:
            _context.next = 25;
            return (0, _asyncHelper.readFileAsync)(detectedFiles[i]);

          case 25:
            content = _context.sent;

            if (!(content.indexOf("interface ") >= 0 && content.indexOf("class ") < 0)) {
              _context.next = 31;
              break;
            }

            // to ignore interfaces
            interfaces.push(relative);
            return _context.abrupt("continue", 32);

          case 31:
            pathMap[relative] = _path2.default.parse(relative);

          case 32:
            i++;
            _context.next = 18;
            break;

          case 35:
            if (_yargs.argv.debug) {
              console.log(_chalk2.default.cyan("Target files:\n"));
              for (key in pathMap) {
                console.log(_chalk2.default.cyan(key + " : \"" + pathMap[key] + "\""));
              }
            }
            // separate relative path by '/' or '\'
            separated = {};

            for (keyPath in pathMap) {
              separated[keyPath] = pathMap[keyPath].dir.split(_path2.default.sep);
              separated[keyPath].push(pathMap[keyPath].name); // last element of separated[path] is file name without extension
            }
            // make structure of index
            structureObject = {};

            for (_keyPath in separated) {
              generateStructureRecursively(structureObject, separated[_keyPath], "");
            }
            jsonCode = (0, _stringify2.default)(structureObject, null, "  ");
            objectCode = asJSIndex(jsonCode, separated);
            imports = [];

            for (_keyPath2 in separated) {
              imports.push({
                path: "./" + _keyPath2.replace(/\.js|\.ts/g, ""),
                key: (0, _common.jsSafeString)(separated[_keyPath2].reduce(function (p, c) {
                  return p + c;
                }))
              });
            }
            index = 0;
            _iteratorNormalCompletion = true;
            _didIteratorError = false;
            _iteratorError = undefined;
            _context.prev = 48;

            for (_iterator = (0, _getIterator3.default)(interfaces); !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              pathes = _step.value;

              index++;
              imports.push({
                path: "./" + pathes.replace(/\.ts/g, ""),
                key: "__INTERFACE__" + index
              });
            }
            _context.next = 56;
            break;

          case 52:
            _context.prev = 52;
            _context.t2 = _context["catch"](48);
            _didIteratorError = true;
            _iteratorError = _context.t2;

          case 56:
            _context.prev = 56;
            _context.prev = 57;

            if (!_iteratorNormalCompletion && _iterator.return) {
              _iterator.return();
            }

          case 59:
            _context.prev = 59;

            if (!_didIteratorError) {
              _context.next = 62;
              break;
            }

            throw _iteratorError;

          case 62:
            return _context.finish(59);

          case 63:
            return _context.finish(56);

          case 64:
            templateArgs = {
              exportObject: objectCode,
              importCore: _yargs.argv.core ? "" : 'import gr from "grimoirejs";',
              registerNamespace: _yargs.argv.core ? "" : "gr.notifyRegisteringPlugin(__NAME__);",
              imports: imports,
              mainPath: "./" + _path2.default.relative(basePath, mainFileLocation).replace(/\.ts|\.js/g, ""),
              registerCode: _yargs.argv.core ? "(<any>window)[\"GrimoireJS\"][\"__VERSION__\"]=__VERSION__;\n" : "(<any>window)[\"GrimoireJS\"].lib." + projectSuffix + " = __EXPOSE__;",
              version: pkgJson.version,
              name: pkgJson.name
            };
            _context.next = 67;
            return (0, _asyncHelper.templateAsync)(_path2.default.normalize(__dirname + "/../../src/buildUtil/index-template.template"), templateArgs);

          case 67:
            index_ts_content = _context.sent;
            dest_path = _path2.default.join(cwd, _yargs.argv.dest);
            _context.next = 71;
            return (0, _asyncHelper.existsAsync)(dest_path);

          case 71:
            _context.t3 = !_context.sent;

            if (_context.t3) {
              _context.next = 78;
              break;
            }

            _context.t4 = index_ts_content;
            _context.next = 76;
            return (0, _asyncHelper.readFileAsync)(dest_path);

          case 76:
            _context.t5 = _context.sent;
            _context.t3 = _context.t4 !== _context.t5;

          case 78:
            if (!_context.t3) {
              _context.next = 81;
              break;
            }

            _context.next = 81;
            return (0, _asyncHelper.writeFileAsync)(dest_path, index_ts_content);

          case 81:
            _context.next = 86;
            break;

          case 83:
            _context.prev = 83;
            _context.t6 = _context["catch"](0);

            console.log(_context.t6);

          case 86:
          case "end":
            return _context.stop();
        }
      }
    }, _callee, this, [[0, 83], [48, 52, 56, 64], [57,, 59, 63]]);
  }));

  return function generateIndex() {
    return _ref.apply(this, arguments);
  };
}();

var _asyncHelper = require("../async-helper");

var _yargs = require("yargs");

var _path = require("path");

var _path2 = _interopRequireDefault(_path);

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

var _common = require("./common");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function generateStructureRecursively(obj, sepDirs, basePath) {
  if (sepDirs.length < 2) {
    return;
  }
  if (sepDirs[0] === '') {
    obj[sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
    return;
  }
  basePath = basePath + sepDirs[0];
  if (sepDirs[0] !== '' && obj[sepDirs[0]] === void 0) {
    obj[sepDirs[0]] = {};
  }
  if (sepDirs.length > 2) {
    generateStructureRecursively(obj[sepDirs[0]], sepDirs.slice(1), basePath);
  } else if (sepDirs.length === 2) {
    obj[sepDirs[0]][sepDirs[1]] = (0, _common.jsSafeString)(basePath + sepDirs[1]);
  }
}

function asJSIndex(jsonStr, sepDirs) {
  for (var pathKey in sepDirs) {
    var keyName = (0, _common.jsSafeString)(sepDirs[pathKey].reduce(function (p, c) {
      return p + c;
    }));
    var regex = new RegExp("(: *)\"" + keyName + "\"");
    jsonStr = jsonStr.replace(regex, "$1" + keyName);
  }
  return jsonStr;
}

generateIndex();
